==> haskell-persistent-mysql-2.13.1.5-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-5wqgrgEie6gGaTIiAofm6q
key:                  persistent-mysql-2.13.1.5-5wqgrgEie6gGaTIiAofm6q
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  10a706b3ce5a3233b19425d2eb8ce601
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-5wqgrgEie6gGaTIiAofm6q
depends:
    aeson-2.1.2.1-HvDDR856aNq5cfhhuYXFVB base-4.17.2.1
    blaze-builder-0.4.4-IUOXk9qX0ZPB9EabAhi3MJ bytestring-0.11.5.3
    conduit-1.3.6.1-LSEd28HkJLcLIWho4Hpdv5 containers-0.6.7
    monad-logger-0.3.42-9OgDnhfMjyd9Av4VLmtX3H
    mysql-0.2.1-ByPYg5Dbc5aD8D74MTCd12
    mysql-simple-0.4.9-KJJUKiZ7oB0HRx2EW5Q7P2
    persistent-2.14.5.2-pL8CUNpFRG4IGlDbfxpgZ
    resource-pool-0.2.3.2-HUkc9HJXInv4C6Fq6cZIPI
    resourcet-1.2.6-7iKUUdP710zAH2Mxgc0pA5 text-2.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-mysql-2.13.1.5-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-59Bc0ZDoVjS77DITxjZvFg
key:                  persistent-mysql-2.13.1.5-59Bc0ZDoVjS77DITxjZvFg
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  d44f50fc02e6c44cddf8e347415df8df
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-59Bc0ZDoVjS77DITxjZvFg
depends:
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig base-4.17.2.1
    blaze-builder-0.4.4-IUOXk9qX0ZPB9EabAhi3MJ bytestring-0.11.5.3
    conduit-1.3.6.1-3M1B5TjJPZk646ipFSI00d containers-0.6.7
    monad-logger-0.3.42-4BD4tPRsf4bJhu9KrtN65n
    mysql-0.2.1-ByPYg5Dbc5aD8D74MTCd12
    mysql-simple-0.4.9-KJJUKiZ7oB0HRx2EW5Q7P2
    persistent-2.14.5.2-2YgOdj5jaNvOPobmvEEoZ
    resource-pool-0.2.3.2-HUkc9HJXInv4C6Fq6cZIPI
    resourcet-1.2.6-7iKUUdP710zAH2Mxgc0pA5 text-2.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
